NAME

Config::Model::models::Xorg::ServerFlags - Configuration class Xorg::ServerFlags

VERSION

version 1.111

DESCRIPTION

Configuration classes used by Config::Model

Elements

DefaultServerLayout

This specifies the default ServerLayout section to use in the absence of the layout command line option. Optional. Type reference.

NoTrapSignals

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

DontVTSwitch

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

DontZap

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

DontZoom

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

DisableVidModeExtension

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

AllowNonLocalXvidtune

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

DisableModInDev

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

AllowMouseOpenFail

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

VTSysReq

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

XkbDisable

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

NoPM

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

Xinerama

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

AllowDeactivateGrabs

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

AllowClosedownGrabs

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

IgnoreABI

This disables the parts of the Xorg-Misc extension that can be used to modify the input device settings dynamically. Default: that functionality is enabled. Optional. Type boolean. upstream_default: '0'.

VTInit

Runs command after the VT used by the server has been opened. The command string is passed to "/bin/sh -c", and is run with the real user's id with stdin and stdout set to the VT. The purpose of this option is to allow system dependent VT initialisation commands to be run. This option should rarely be needed. Default: not set. Optional. Type uniline.

BlankTime

sets the inactivity timeout for the blank phase of the screensaver. time is in minutes. This is equivalent to the Xorg server's -s flag, and the value can be changed at run-time with xset(1). Default: 10 minutes. Optional. Type integer. upstream_default: '10'.

StandbyTime

sets the inactivity timeout for the standby phase of DPMS mode. time is in minutes, and the value can be changed at run-time with xset(1). Default: 20 minutes. This is only suitable for VESA DPMS compatible monitors, and may not be supported by all video drivers. It is only enabled for screens that have the "DPMS" option set (see the MONITOR section below). Optional. Type integer. upstream_default: '20'.

SuspendTime

sets the inactivity timeout for the suspend phase of DPMS mode. time is in minutes, and the value can be changed at run-time with xset(1). Default: 30 minutes. This is only suitable for VESA DPMS compatible monitors, and may not be supported by all video drivers. It is only enabled for screens that have the "DPMS" option set (see the MONITOR section below). Optional. Type integer. upstream_default: '30'.

OffTime

sets the inactivity timeout for the off phase of DPMS mode. time is in minutes, and the value can be changed at run-time with xset(1). Default: 40 minutes. This is only suitable for VESA DPMS compatible monitors, and may not be supported by all video drivers. It is only enabled for screens that have the "DPMS" option set (see the MONITOR section below). Optional. Type integer. upstream_default: '40'.

Pixmap

This sets the pixmap format to use for depth 24. Allowed values for bpp are 24 and 32. Default: 32 unless driver constraints don't allow this (which is rare). Note: some clients don't behave well when this value is set to 24. Optional. Type enum. choice: '24', '32'. upstream_default: '32'.

PC98

Specify that the machine is a Japanese PC-98 machine. This should not be enabled for anything other than the Japanese-specific PC-98 architecture. Default: auto-detected. Optional. Type boolean.

HandleSpecialKeys

This option controls when the server uses the builtin handler to process special key combinations (such as Ctrl+Alt+Backspace). Normally the XKEYBOARD extension keymaps will provide mappings for each of the special key combinations, so the builtin handler is not needed unless the XKEYBOARD extension is disabled. The value of when can be Always, Never, or WhenNeeded. Default: Use the builtin handler only if needed. The server will scan the keymap for a mapping to the Terminate action and, if found, use XKEYBOARD for processing actions, otherwise the builtin handler will be used. Optional. Type enum. choice: 'Always', 'Never', 'WhenNeeded'. upstream_default: 'WhenNeeded'.

AIGLX

enable or disable AIGLX. Optional. Type enum. choice: 'off', 'on'. upstream_default: 'on'.

UseDefaultFontPath

Include the default font path even if other paths are specified in xorg.conf. If enabled, other font paths are included as well. Optional. Type enum. choice: 'off', 'on'. upstream_default: 'on'.

SEE ALSO